@@ -64,6 +64,7 @@
 
 /* Set to true when the config should be reloaded */
 gboolean reread_config;
+guint visor_timeout_id = -1;
 
 gint device_equal_by_io (GPilotDevice *,GIOChannel *);
 gboolean device_in (GIOChannel *,
@@ -835,9 +836,9 @@ static gboolean product_net[] =
 };
 
 static gboolean 
-visor_devices_in (GIOChannel *io_channel,
-		 GIOCondition condition,
-		 GPilotContext *context) {
+visor_devices_timeout (gpointer data) 
+{
+	GPilotContext *context = data;
 	GPilotDevice *device;
 	GList *l;
 	int i;
@@ -849,8 +850,6 @@ visor_devices_in (GIOChannel *io_channel,
 
 	g_assert (context != NULL);
 
-	sleep (2);	
-
 	if (context->paused) 
 		return FALSE;
 
@@ -896,24 +895,12 @@ visor_devices_in (GIOChannel *io_channel,
 	return TRUE;
 }
 
-static gboolean 
-visor_devices_err (GIOChannel *io_channel,
-	   GIOCondition condition,
-	   GPilotContext *context) 
+#endif
+#endif
+
+void monitor_channel (GPilotDevice *dev,GPilotContext *context) 
 {
 	g_assert (context != NULL);
-
-	gpilot_gui_warning_dialog ("Read error on /proc/bus/usb/devices"); 
-	g_warning ("Read error on /proc/bus/usb/devices");
-
-	return FALSE;
-}
-
-#endif
-#endif
-
-void monitor_channel (GPilotDevice *dev,GPilotContext *context) {
-	g_assert (context != NULL);
 	
 	if (dev->type == PILOT_DEVICE_SERIAL
 	    || dev->type == PILOT_DEVICE_IRDA) {
@@ -944,25 +931,8 @@ void monitor_channel (GPilotDevice *dev,GPilotContext *context) {
 		/* We want to watch the /proc/bus/usb/devices file once 
 		 * per context, and then check all devices each time it is
 		 * woken up. */
-		if (context->visor_fd == -1) {
-			context->visor_fd = open ("/proc/bus/usb/devices",
-						  O_RDONLY);
-			if (context->visor_fd == -1) {
-				g_warning ("Could not open /proc/bus/usb/devices - make sure you have the usbdevfs properly configured and mounted.");
-				return;
-			}
-			context->visor_io = 
-				g_io_channel_unix_new (context->visor_fd);
-			context->visor_in_handle = 
-				g_io_add_watch (context->visor_io,
-						G_IO_IN,
-						(GIOFunc)visor_devices_in,
-						(gpointer)context);
-			context->visor_err_handle = 
-				g_io_add_watch (context->visor_io,
-						G_IO_ERR|G_IO_PRI|G_IO_HUP|G_IO_NVAL,
-						(GIOFunc)visor_devices_err,
-						(gpointer)context);
+		if (visor_timeout_id == -1) {
+			visor_timeout_id = g_timeout_add (2000, visor_devices_timeout, context);
 		}
 #else /* linux*/
 		g_assert_not_reached ();
